#import "AppDelegate.h"
#import "ViewController.h"
#import <sqlite3.h>
#import "Item.h"

@implementation AppDelegate

@synthesize window = _window;
@synthesize viewController;
@synthesize array,databaseName,databasePath, navigationController;


- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions

{
    [[NSUserDefaults standardUserDefaults] setBool:NO forKey:@"isTwitterDB"];
    [[NSUserDefaults standardUserDefaults] synchronize];
    [self copyDatabaseIfNeeded];
	
	//Initialize the coffee array.
	NSMutableArray *tempArray = [[NSMutableArray alloc] init];
	self.array = tempArray;
	
	//Once the db is copied, get the initial data to display on the screen.
	[Item getInitialDataToDisplay:[self getDBPath]];
	
    // Add the navigation controller's view to the window and display.

    [self.window makeKeyAndVisible];
    return YES;
}

- (void)applicationWillResignActive:(UIApplication *)application
{
    
}

- (void) copyDatabaseIfNeeded {
	
	//Using NSFileManager we can perform many file system operations.
	NSFileManager *fileManager = [NSFileManager defaultManager];
	NSError *error;
	NSString *dbPath = [self getDBPath];
	BOOL success = [fileManager fileExistsAtPath:dbPath]; 
	
	if(!success) {
		
		NSString *defaultDBPath = [[[NSBundle mainBundle] resourcePath] stringByAppendingPathComponent:NSLocalizedString(@"it.lproj/Mydatabase.sqlite", @"")];
		success = [fileManager copyItemAtPath:defaultDBPath toPath:dbPath error:&error];
		
		if (!success) 
			NSAssert1(0, @"Failed to create writable database file with message '%@'.", [error localizedDescription]);
	}	
}

- (NSString *) getDBPath {
	
    //Search for standard documents using NSSearchPathForDirectoriesInDomains
	//First Param = Searching the documents directory
	//Second Param = Searching the Users directory and not the System
	//Expand any tildes and identify home directories.
	NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory , NSUserDomainMask, YES);
	NSString *documentsDir = [paths objectAtIndex:0];
	return [documentsDir stringByAppendingPathComponent:@"Mydatabase.sqlite"];
}

-(void)Additem:(Item*)itemobj {
	
	//Add it to the database.
	[itemobj addItem];
	
	//Add it to the coffee array.
	[array addObject:itemobj];
}

-(void)removeitem:(Item *)itmobj {
	
	//Delete it from the database.
	[itmobj deleteItem ];
	
	//Remove it from the array.
	[array removeObject:itmobj];
}


- (void)applicationDidEnterBackground:(UIApplication *)application
{
	
}

- (void)applicationWillEnterForeground:(UIApplication *)application
{
	
}

- (void)applicationDidBecomeActive:(UIApplication *)application
{
	
}

- (void)applicationWillTerminate:(UIApplication *)application
{
    [Item finalizeStatements];

}

@end
