//
//  Item.m
//  InsertData
//
//  Created by Sam Gupta on 28/01/11.
//  Copyright 2011 Cross. All rights reserved.
//

#import "Item.h"
#import "AppDelegate.h"

static sqlite3 *database = nil;
static sqlite3_stmt *deleteStmt = nil;
static sqlite3_stmt *addStmt = nil;

@implementation Item

@synthesize name,address,rowID,isDirty,isDetailViewHydrated;


- (id) initWithPrimaryKey:(NSInteger) pk {
	
	self = [super init];
	rowID = pk;
	
	isDetailViewHydrated = NO;
	
	return self;
}




+ (void) getInitialDataToDisplay:(NSString *)dbPath {
	
	AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
	
	if (sqlite3_open([dbPath UTF8String], &database) == SQLITE_OK) {
		
		const char *sql = "select  rowid,name, address from employee";
		sqlite3_stmt *selectstmt;
		if(sqlite3_prepare_v2(database, sql, -1, &selectstmt, NULL) == SQLITE_OK) {
			
			while(sqlite3_step(selectstmt) == SQLITE_ROW) {
				NSInteger primaryKey = sqlite3_column_int(selectstmt, 0);

				//NSInteger primaryKey = sqlite3_column_int(selectstmt, 0);
				Item *Obj = [[Item alloc]initWithPrimaryKey:primaryKey];
				Obj.name = [NSString stringWithUTF8String:(char *)sqlite3_column_text(selectstmt, 1)];
				Obj.address=[NSString stringWithUTF8String:(char *)sqlite3_column_text(selectstmt, 2)];
				Obj.isDirty = NO;
				[appDelegate.array addObject:Obj];
			}
		}
	}
	else
		sqlite3_close(database); //Even though the open call failed, close the database connection to release all the memory.
}

+ (void) finalizeStatements {
	
	if(database) sqlite3_close(database);
	if(deleteStmt) sqlite3_finalize(deleteStmt);
	if(addStmt) sqlite3_finalize(addStmt);
}

/*
// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void)drawRect:(CGRect)rect {
    // Drawing code
}
*/
- (void) deleteItem {
	
	if(deleteStmt == nil) {
		const char *sql = "delete from employee where rowID = ?";
		if(sqlite3_prepare_v2(database, sql, -1, &deleteStmt, NULL) != SQLITE_OK)
			NSAssert1(0, @"Error while creating delete statement. '%s'", sqlite3_errmsg(database));
	}
	
	//When binding parameters, index starts from 1 and not zero.
	sqlite3_bind_int(deleteStmt, 1, rowID);
	
	if (SQLITE_DONE != sqlite3_step(deleteStmt)) 
		NSAssert1(0, @"Error while deleting. '%s'", sqlite3_errmsg(database));
    	
	sqlite3_reset(deleteStmt);
}


-(void)addItem{
	
	if(addStmt == nil) {
		const char *sql = "insert into employee(name, address) Values(?, ?)";
		if(sqlite3_prepare_v2(database, sql, -1, &addStmt, NULL) != SQLITE_OK)
			NSAssert1(0, @"Error while creating add statement. '%s'", sqlite3_errmsg(database));
	}
	
	sqlite3_bind_text(addStmt, 1, [name UTF8String], -1, SQLITE_TRANSIENT);
	sqlite3_bind_text(addStmt, 2, [address UTF8String], -1, SQLITE_TRANSIENT);
	NSLog(@"%@",name);
	NSLog(@"%@",address);
	if(SQLITE_DONE != sqlite3_step(addStmt))
		NSAssert1(0, @"Error while inserting data. '%s'", sqlite3_errmsg(database));
	else
		//SQLite provides a method to get the last primary key inserted by using sqlite3_last_insert_rowid
		rowID = sqlite3_last_insert_rowid(database);
	
	//Reset the add statement.
	sqlite3_reset(addStmt);
}


@end